derive_ruda_comptime

Attribute Macro derive_ruda_comptime 

#[derive_ruda_comptime]
Attribute macro to define a type that can be used as a kernel comptime argument This derive Debug, Hash, PartialEq, Eq, Clone, Copy