pub fn load<C: RudaPrimitive, V: RudaPrimitive>(
mat: &Matrix<C>,
value: &Slice<V>,
stride: u32,
)Expand description
Load the matrix with the provided array using the stride.
pub fn load<C: RudaPrimitive, V: RudaPrimitive>(
mat: &Matrix<C>,
value: &Slice<V>,
stride: u32,
)Load the matrix with the provided array using the stride.