pub type N = DynamicSize<_N>;Expand description
Type to be used as a generic for launch kernel argument.
Aliased Type
pub struct N { /* private fields */ }pub type N = DynamicSize<_N>;Type to be used as a generic for launch kernel argument.
pub struct N { /* private fields */ }