Module synchronization

Module synchronization 

Modules

sync_async_proxy_shared
sync_plane
sync_ruda
sync_storage

Functions

sync_async_proxy_shared
sync_async_proxy_shared is a synchronization fence for the experimental SM 9.0+ copy functions, applying bidirectionally between the async proxy (i.e. TMA) and shared memory. Should be used after initializing the barriers, and before the copy operation. PTX: fence.proxy.async.shared::cta Experimental and subject to change.
sync_plane
Synchronizes units within their plane (e.g., warp or SIMD group).
sync_ruda
Coordinates the following among all invocations in the current ruda:
sync_storage
Sync_storage is the same but change “ruda address space(shared memory)” to “storage address space(input args)”. But the set of invocations that are collaborating is still only the invocations in the same ruda.There is no guarantee about using barriers alone to make the writes to storage buffer in one ruda become visible to invocations in a different ruda.