sync_ruda

Function sync_ruda 

pub fn sync_ruda()
Coordinates the following among all invocations in the current ruda:

  • Memory writes to variables in ruda address space(shared memory) complete, e.g. writes that were initiated actually land in the ruda address space memory.

  • Then all the invocations in the ruda wait for each other to arrive at the barrier, i.e. this step.

  • Then all the invocations int the ruda begin executing after the barrier, and all writes to ruda address space made before the barrier are now visible to any invocation in this ruda.