Reinterpret

Trait Reinterpret 

pub trait Reinterpret: RudaPrimitive {
    // Provided methods
    fn reinterpret<From: RudaPrimitive>(value: From) -> Self { ... }
    fn reinterpret_vectorization<From: RudaPrimitive>() -> usize { ... }
    fn __expand_reinterpret<From: RudaPrimitive>(
        scope: &mut Scope,
        value: NativeExpand<From>,
    ) -> <Self as RudaType>::ExpandType { ... }
    fn __expand_reinterpret_vectorization<From: RudaPrimitive>(
        scope: &mut Scope,
    ) -> usize { ... }
}
Enables reinterpetring the bits from any value to any other type of the same size.

Provided Methods

fn reinterpret<From: RudaPrimitive>(value: From) -> Self

Reinterpret the bits of another primitive as this primitive without conversion.

fn reinterpret_vectorization<From: RudaPrimitive>() -> usize

Calculates the expected vectorization for the reinterpret target

fn __expand_reinterpret<From: RudaPrimitive>( scope: &mut Scope, value: NativeExpand<From>, ) -> <Self as RudaType>::ExpandType

fn __expand_reinterpret_vectorization<From: RudaPrimitive>( scope: &mut Scope, ) -> usize

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors