RudaComptime

Trait RudaComptime 

pub trait RudaComptime:
    Debug
    + Hash
    + Eq
    + Clone
    + Copy { }
A type that can be used as a kernel comptime argument. Note that a type doesn’t need to implement RudaComptime to be used as a comptime argument. However, this facilitate the declaration of generic ruda types.

Example

ⓘ
#[derive(RudaType)]
pub struct Example<A: RudaType, B: RudaComptime> {
    a: A,
    #[ruda(comptime)]
    b: B
}

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> RudaComptime for T
where T: Debug + Hash + Eq + Clone + Copy,