Module unaligned_vector

Module unaligned_vector 

Traits

UnalignedVector
An extension trait for expanding the ruda frontend with the ability to request unaligned vector reads and writes
UnalignedVectorExpand
An extension trait for expanding the ruda frontend with the ability to request unaligned vector reads and writes