CoopMma

Enum CoopMma 

pub enum CoopMma {
    Fill {
        value: Variable,
    },
    Load {
        value: Variable,
        stride: Variable,
        offset: Variable,
        layout: Option<MatrixLayout>,
    },
    Execute {
        mat_a: Variable,
        mat_b: Variable,
        mat_c: Variable,
    },
    Store {
        mat: Variable,
        stride: Variable,
        offset: Variable,
        layout: MatrixLayout,
    },
    Cast {
        input: Variable,
    },
    RowIndex {
        lane_id: Variable,
        i: Variable,
        matrix: Matrix,
    },
    ColIndex {
        lane_id: Variable,
        i: Variable,
        matrix: Matrix,
    },
    LoadMatrix {
        buffer: Variable,
        offset: Variable,
        vector_size: Option<usize>,
        factor: usize,
        transpose: bool,
    },
    StoreMatrix {
        offset: Variable,
        vector_size: Option<usize>,
        registers: Variable,
        factor: usize,
        transpose: bool,
    },
    ExecuteManual {
        matrix: Matrix,
        registers_a: Variable,
        registers_b: Variable,
        registers_c: Variable,
    },
    ExecuteScaled {
        matrix: Matrix,
        registers_a: Variable,
        registers_b: Variable,
        registers_c: Variable,
        scales_a: Variable,
        scales_b: Variable,
        scales_factor: usize,
    },
}
Cooperative Matrix-Multiply and Accumulate Instruction.

Variants



Fill

Fill the matrix with the value.

Fields

value: Variable


Load

Load the value into the matrix given the stride.

Fields

value: Variable
stride: Variable
offset: Variable


Execute

Executes D=A*B+C;

For implementing a matmul, D=C : C+=A*B

Fields

mat_a: Variable
mat_b: Variable
mat_c: Variable


Store

Store the matrix in an output variable following the stride and the layout.

Fields

stride: Variable
offset: Variable


Cast

Cast a fragment to another type.

Fields

input: Variable


RowIndex

Row index of nth element in the lane

Fields

lane_id: Variable
matrix: Matrix


ColIndex

Column index of nth element in the lane

Fields

lane_id: Variable
matrix: Matrix


LoadMatrix

Execute a CUDA ldmatrix instruction

Fields

buffer: Variable
offset: Variable
vector_size: Option<usize>
factor: usize
transpose: bool


StoreMatrix

Execute a CUDA stmatrix instruction

Fields

offset: Variable
vector_size: Option<usize>
registers: Variable
factor: usize
transpose: bool


ExecuteManual

Manual execute.

Fields

matrix: Matrix
registers_a: Variable
registers_b: Variable
registers_c: Variable


ExecuteScaled

Scaled manual execute.

Fields

matrix: Matrix
registers_a: Variable
registers_b: Variable
registers_c: Variable
scales_a: Variable
scales_b: Variable
scales_factor: usize