RudaDim

Struct RudaDim 

pub struct RudaDim {
    pub x: u32,
    pub y: u32,
    pub z: u32,
}
The number of units across all 3 axis totalling to the number of working units in a ruda.

Fields

x: u32

The number of units in the x axis.

y: u32

The number of units in the y axis.

z: u32

The number of units in the z axis.

Implementations

Source

impl RudaDim

pub fn new(properties: &DeviceProperties, working_units: usize) -> RudaDim

Creates a new RudaDim based on the maximum number of tasks that can be parellalized by units, in other words, by the maximum number of working units.

Notes

For complex problems, you probably want to have your own logic function to create the RudaDim, but for simpler problems such as elemwise-operation, this is a great default.

pub const fn new_single() -> RudaDim

Create a new ruda dim with x = y = z = 1.

pub const fn new_1d(x: u32) -> RudaDim

Create a new ruda dim with the given x, and y = z = 1.

pub const fn new_2d(x: u32, y: u32) -> RudaDim

Create a new ruda dim with the given x and y, and z = 1.

pub const fn new_3d(x: u32, y: u32, z: u32) -> RudaDim

Create a new ruda dim with the given x, y and z. This is equivalent to the new function.

pub const fn num_elems(&self) -> u32

Total numbers of units per ruda

pub const fn can_contain(&self, other: RudaDim) -> bool

Whether this RudaDim can fully contain other