intrinsic

Macro intrinsic 

intrinsic!() { /* proc-macro */ }
Mark the contents of this macro as an intrinsic, turning off all expansion for this code and calling it with the scope

Example

#use ruda_kernel_macros::ruda;
#[ruda]
fn do_stuff(input: u32) -> u32 {
    let comptime_value = intrinsic! { |scope| u32::elem_size(scope) };
    input + comptime_value
}