Module numeric

Module numeric 

Custom float implementations

Structs

e2m1
A 4-bit floating point type with 2 exponent bits and 1 mantissa bit.
e2m3
A 6-bit floating point type with 2 exponent bits and 3 mantissa bits.
e2m1x2
A 4-bit floating point type with 2 exponent bits and 1 mantissa bit. Packed with two elements per value, to allow for conversion to/from bytes. Care must be taken to ensure the shape is adjusted appropriately.
e3m2
A 6-bit floating point type with 3 exponent bits and 2 mantissa bits.
e4m3
A 8-bit floating point type with 4 exponent bits and 3 mantissa bits.
e5m2
A 8-bit floating point type with 5 exponent bits and 2 mantissa bits.
flex32
A floating point type with relaxed precision, minimum f16, max f32.
tf32
A 19-bit floating point type implementing the tfloat32 format.
ue8m0
An 8-bit unsigned floating point type with 8 exponent bits and no mantissa bits. Used for scaling factors.