#[derive(RudaType)]
{
// Attributes available to this derive:
#[ruda]
}
Derive macro to define a ruda type that is not launched
#[derive(RudaType)]
{
// Attributes available to this derive:
#[ruda]
}
Derive macro to define a ruda type that is not launched