comptime_type!() { /* proc-macro */ }Expand description
Makes the function return a compile time value Useful in a ruda trait to have a part of the trait return comptime values
Example
#use ruda_kernel_macros::ruda;
#[ruda]
fn do_stuff(#[comptime] input: u32) -> comptime_type!(u32) {
input + 5
}TODO: calling a trait method returning comptime_type from
within another trait method does not work