RudaCountSelection

Enum RudaCountSelection 

pub enum RudaCountSelection {
    Exact(RudaCount),
    Approx(RudaCount, u32),
}
Defines how to select ruda count based on the number of rudas required.

Variants



Exact(RudaCount)

If the number of rudas is the same as required.



Approx(RudaCount, u32)

If the number of rudas isn’t the same as required.

This can happen based on the hardware limit, requiring the kernel to perform OOB checks.

Implementations

Source

impl RudaCountSelection

pub fn new<R>(client: &ComputeClient<R>, num_rudas: u32) -> RudaCountSelection
where R: Runtime,

Creates a RudaCount while respecting the hardware limits.

pub fn has_idle(&self) -> bool

If some rudas will be idle.

pub fn ruda_count(self) -> RudaCount

Converts into RudaCount.