pub struct RudaDim {
pub x: u32,
pub y: u32,
pub z: u32,
}Expand description
The number of units across all 3 axis totalling to the number of working units in a ruda.
Fields
x: u32The number of units in the x axis.
y: u32The number of units in the y axis.
z: u32The number of units in the z axis.
Implementations
Sourceimpl RudaDim
impl RudaDim
Sourcepub fn new(properties: &DeviceProperties, working_units: usize) -> RudaDim
pub fn new(properties: &DeviceProperties, working_units: usize) -> RudaDim
Creates a new RudaDim based on the maximum number of tasks that can be parellalized by units, in other words,
by the maximum number of working units.
Notes
For complex problems, you probably want to have your own logic function to create the
RudaDim, but for simpler problems such as elemwise-operation, this is a great default.
Sourcepub const fn new_single() -> RudaDim
pub const fn new_single() -> RudaDim
Create a new ruda dim with x = y = z = 1.
Sourcepub const fn new_2d(x: u32, y: u32) -> RudaDim
pub const fn new_2d(x: u32, y: u32) -> RudaDim
Create a new ruda dim with the given x and y, and z = 1.
Sourcepub const fn new_3d(x: u32, y: u32, z: u32) -> RudaDim
pub const fn new_3d(x: u32, y: u32, z: u32) -> RudaDim
Create a new ruda dim with the given x, y and z. This is equivalent to the new function.
Sourcepub const fn can_contain(&self, other: RudaDim) -> bool
pub const fn can_contain(&self, other: RudaDim) -> bool
Whether this RudaDim can fully contain other