Indexing Utilities
Structs
- Index
Wrap - Wraps an index with negative indexing support.
Enums
- Indexing
Update Op - Computation to be used to update the existing values in indexed assignment operations (scatter/select).
Traits
- AsIndex
- Helper trait for implementing indexing with support for negative indices.
- AsSize
- Types which can be converted to a
usizeSize.
Functions
- ravel_
index - Compute the ravel index for the given coordinates.
- wrap_
index - Wraps a dimension index to be within the bounds of the dimension size.