DeformConvOptions

Struct DeformConvOptions 

pub struct DeformConvOptions<const N: usize> {
    pub stride: [usize; N],
    pub padding: [usize; N],
    pub dilation: [usize; N],
    pub weight_groups: usize,
    pub offset_groups: usize,
    pub padding_end: Option<[usize; N]>,
}
Convolution options.

Fields

stride: [usize; N]

Stride (non-zero).

padding: [usize; N]

Padding.

dilation: [usize; N]

Dilation (non-zero).

weight_groups: usize

Weight Groups (non-zero).

offset_groups: usize

Offset Groups (non-zero).

padding_end: Option<[usize; N]>

End padding per dimension, or None to use symmetric padding.

Implementations

Source

impl<const N: usize> DeformConvOptions<N>

pub fn new( stride: [usize; N], padding: [usize; N], dilation: [usize; N], weight_groups: usize, offset_groups: usize, ) -> DeformConvOptions<N>

Constructs a new DeformConvOptions.

pub fn with_padding_end(self, padding_end: [usize; N]) -> DeformConvOptions<N>

Set end padding while retaining padding as the sampling grid’s start padding.

pub fn output_size(&self, input: [usize; N], kernel: [usize; N]) -> [usize; N]

Calculate output spatial dimensions with the configured dilation and padding.