Module reshape

Module reshape 

Enums

ReshapeAction
The action to take for a reshape operation.
ReshapeAnalysis
The reshape kind.

Functions

broadcast_strides
Calculate the new strides given added batch dimensions.
contiguous_strides
Computes the strides for a contiguous tensor with the given shape.
is_contiguous
Check if the current tensor is contiguous.
reshape_action
Returns the proper action to take when reshaping a tensor.
reshape_analysis
Returns the analysis of a reshape operation.
split_strides
Calculate the new strides given added split dimensions.