RudaTask

Trait RudaTask 

pub trait RudaTask<C>:
    KernelMetadata
    + Send
    + Sync
where C: Compiler,
{ // Required method fn compile( &self, compiler: &mut C, compilation_options: &<C as Compiler>::CompilationOptions, mode: ExecutionMode, address_type: StorageType, ) -> Result<CompiledKernel<C>, CompilationError>; // Provided method fn kernel_definition(&self) -> Option<KernelDefinition> { ... } }
Kernel trait with the ComputeShader that will be compiled and cached based on the provided id.

Required Methods

fn compile( &self, compiler: &mut C, compilation_options: &<C as Compiler>::CompilationOptions, mode: ExecutionMode, address_type: StorageType, ) -> Result<CompiledKernel<C>, CompilationError>

Compile a kernel and return the compiled form with an optional non-text representation

Provided Methods

fn kernel_definition(&self) -> Option<KernelDefinition>

Export the shared IR when this task originates from a kernel definition. Source-only tasks do not have an IR representation.