Module indexing

Module indexing 

Indexing Utilities

Structs

IndexWrap
Wraps an index with negative indexing support.

Enums

IndexingUpdateOp
Computation to be used to update the existing values in indexed assignment operations (scatter/select).

Traits

AsIndex
Helper trait for implementing indexing with support for negative indices.
AsSize
Types which can be converted to a usize Size.

Functions

ravel_index
Compute the ravel index for the given coordinates.
wrap_index
Wraps a dimension index to be within the bounds of the dimension size.