Crate ruda_kernel

Crate ruda_kernel 

Ruda Rust kernel DSL and device tensor operations.

Modules

dsl

Macros

debug_print
Print a formatted message using the target’s debug print facilities. The format string is target specific, but Vulkan and CUDA both use the C++ conventions. WGSL isn’t currently supported.
debug_print_expand
Print a formatted message using the target’s debug print facilities. The format string is target specific, but Vulkan and CUDA both use the C++ conventions. WGSL isn’t currently supported.
define
define_scalar
Define a custom type to be used for a comptime scalar type. Useful for cases where generics can’t work.
define_size
Define a custom type to be used for a comptime size. Useful for cases where generics can’t work.
expand_assert
expand_error
size
unexpanded