tensor_vector_size_perpendicular

Function tensor_vector_size_perpendicular 

pub fn tensor_vector_size_perpendicular(
    supported_vector_sizes: impl Iterator<Item = VectorSize>,
    shape: &[usize],
    strides: &[usize],
    axis: usize,
) -> VectorSize
Find the maximum vector size usable for perpendicular vectorization along the given axis from the supported vector sizes or return 1 if vectorization is impossible.

This function is designed to never return a vector size above 1 by error, but doesn’t guarantee to always return the actual maximum possible vector size. That is, it may be overly strict.

Checks that smaller-stride axes form a contiguous span ending at the axis stride, and that the axis stride and every larger stride are divisible by the candidate vector size.