pub trait RudaType {
type ExpandType: Clone + IntoMut + RudaDebug;
}Expand description
Types used in a ruda function must implement this trait
Variables whose values will be known at runtime must
have ManagedVariable as associated type
Variables whose values will be known at compile time
must have the primitive type as associated type
Note: Ruda functions should be written using RudaTypes,
so that the code generated uses the associated ExpandType.
This allows Ruda code to not necessitate cloning, which is cumbersome
in algorithmic code. The necessary cloning will automatically appear in
the generated code.
Required Associated Types
type ExpandType: Clone + IntoMut + RudaDebug
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".