pub type SharedExpand<T> = NativeExpand<Shared<T>>;Aliased Type
pub struct SharedExpand<T> {
pub expand: ManagedVariable,
/* private fields */
}Fields
expand: ManagedVariableMethods from Deref<Target = BarrierExpand>
pub fn __expand_tma_load_1d_method<C1: RudaPrimitive, C2: RudaPrimitive<Scalar = C1::Scalar>>( &self, scope: &mut Scope, source: NativeExpand<TensorMap<C1, Tiled>>, destination: SliceExpand<C2, ReadWrite>, x: NativeExpand<i32>, )
pub fn __expand_tma_load_2d_method<C1: RudaPrimitive, C2: RudaPrimitive<Scalar = C1::Scalar>>( &self, scope: &mut Scope, source: NativeExpand<TensorMap<C1, Tiled>>, destination: SliceExpand<C2, ReadWrite>, y: NativeExpand<i32>, x: NativeExpand<i32>, )
pub fn __expand_tma_load_3d_method<C1: RudaPrimitive, C2: RudaPrimitive<Scalar = C1::Scalar>>( &self, scope: &mut Scope, source: NativeExpand<TensorMap<C1, Tiled>>, destination: SliceExpand<C2, ReadWrite>, z: NativeExpand<i32>, y: NativeExpand<i32>, x: NativeExpand<i32>, )
pub fn __expand_tma_load_4d_method<C1: RudaPrimitive, C2: RudaPrimitive<Scalar = C1::Scalar>>( &self, scope: &mut Scope, source: NativeExpand<TensorMap<C1, Tiled>>, destination: SliceExpand<C2, ReadWrite>, w: NativeExpand<i32>, z: NativeExpand<i32>, y: NativeExpand<i32>, x: NativeExpand<i32>, )
pub fn __expand_tma_load_5d_method<C1: RudaPrimitive, C2: RudaPrimitive<Scalar = C1::Scalar>>( &self, scope: &mut Scope, source: NativeExpand<TensorMap<C1, Tiled>>, destination: SliceExpand<C2, ReadWrite>, v: NativeExpand<i32>, w: NativeExpand<i32>, z: NativeExpand<i32>, y: NativeExpand<i32>, x: NativeExpand<i32>, )
pub fn __expand_tma_load_im2col_3d_method<C1: RudaPrimitive, C2: RudaPrimitive<Scalar = C1::Scalar>>( &self, scope: &mut Scope, source: NativeExpand<TensorMap<C1, Im2col>>, destination: SliceExpand<C2, ReadWrite>, n: NativeExpand<i32>, w: NativeExpand<i32>, c: NativeExpand<i32>, w_offset: NativeExpand<u16>, )
pub fn __expand_tma_load_im2col_4d_method<C1: RudaPrimitive, C2: RudaPrimitive<Scalar = C1::Scalar>>( &self, scope: &mut Scope, source: NativeExpand<TensorMap<C1, Im2col>>, destination: SliceExpand<C2, ReadWrite>, n: NativeExpand<i32>, h: NativeExpand<i32>, w: NativeExpand<i32>, c: NativeExpand<i32>, h_offset: NativeExpand<u16>, w_offset: NativeExpand<u16>, )
pub fn __expand_tma_load_im2col_5d_method<C1: RudaPrimitive, C2: RudaPrimitive<Scalar = C1::Scalar>>( &self, scope: &mut Scope, source: NativeExpand<TensorMap<C1, Im2col>>, destination: SliceExpand<C2, ReadWrite>, n: NativeExpand<i32>, d: NativeExpand<i32>, h: NativeExpand<i32>, w: NativeExpand<i32>, c: NativeExpand<i32>, d_offset: NativeExpand<u16>, h_offset: NativeExpand<u16>, w_offset: NativeExpand<u16>, )
pub fn __expand_init_manual_method( &self, scope: &mut Scope, arrival_count: <u32 as RudaType>::ExpandType, ) -> <() as RudaType>::ExpandType
pub fn __expand_memcpy_async_method<C: RudaPrimitive>( &self, scope: &mut Scope, source: <Slice<C> as RudaType>::ExpandType, destination: <SliceMut<C> as RudaType>::ExpandType, ) -> <() as RudaType>::ExpandType
pub fn __expand_memcpy_async_cooperative_method<C: RudaPrimitive>( &self, scope: &mut Scope, source: <Slice<C> as RudaType>::ExpandType, destination: <SliceMut<C> as RudaType>::ExpandType, ) -> <() as RudaType>::ExpandType
pub fn __expand_memcpy_async_tx_method<C: RudaPrimitive>( &self, scope: &mut Scope, source: <Slice<C> as RudaType>::ExpandType, destination: <SliceMut<C> as RudaType>::ExpandType, ) -> <() as RudaType>::ExpandType
pub fn __expand_arrive_method( &self, scope: &mut Scope, ) -> <BarrierToken as RudaType>::ExpandType
pub fn __expand_arrive_and_expect_tx_method( &self, scope: &mut Scope, arrival_count: <u32 as RudaType>::ExpandType, transaction_count: <u32 as RudaType>::ExpandType, ) -> <BarrierToken as RudaType>::ExpandType
pub fn __expand_expect_tx_method( &self, scope: &mut Scope, expected_count: <u32 as RudaType>::ExpandType, ) -> <() as RudaType>::ExpandType
pub fn __expand_arrive_and_wait_method( &self, scope: &mut Scope, ) -> <() as RudaType>::ExpandType
pub fn __expand_wait_method( &self, scope: &mut Scope, token: <BarrierToken as RudaType>::ExpandType, ) -> <() as RudaType>::ExpandType
pub fn __expand_wait_parity_method( &self, scope: &mut Scope, phase: <u32 as RudaType>::ExpandType, ) -> <() as RudaType>::ExpandType
pub fn __expand_commit_copy_async_method( &self, scope: &mut Scope, ) -> <() as RudaType>::ExpandType
Sourcepub fn size(&self) -> VectorSize
pub fn size(&self) -> VectorSize
Comptime version of size.
Sourcepub fn __expand_size_method(&self, _scope: &mut Scope) -> VectorSize
pub fn __expand_size_method(&self, _scope: &mut Scope) -> VectorSize
Expand method of size.
Sourcepub unsafe fn as_type_ref_unchecked<E: RudaType>(&self) -> &NativeExpand<E>
pub unsafe fn as_type_ref_unchecked<E: RudaType>(&self) -> &NativeExpand<E>
Casts a reference of this expand element to a different type.
Safety
There’s no guarantee the new type is valid for the ManagedVariable
Sourcepub unsafe fn as_type_mut_unchecked<E: RudaType>(
&mut self,
) -> &mut NativeExpand<E>
pub unsafe fn as_type_mut_unchecked<E: RudaType>( &mut self, ) -> &mut NativeExpand<E>
Casts a mutable reference of this expand element to a different type.
Safety
There’s no guarantee the new type is valid for the ManagedVariable
Sourcepub fn vector_size(&self) -> VectorSize
pub fn vector_size(&self) -> VectorSize
Comptime version of crate::dsl::frontend::Array::vector_size.
Sourcepub fn constant(&self) -> Option<ConstantValue>
pub fn constant(&self) -> Option<ConstantValue>
Get the ConstantValue from the variable.