pub enum RudaCountSelection {
Exact(RudaCount),
Approx(RudaCount, u32),
}Expand description
Defines how to select ruda count based on the number of rudas required.
Variants
Exact(RudaCount)
If the number of rudas is the same as required.
Approx(RudaCount, u32)
If the number of rudas isn’t the same as required.
This can happen based on the hardware limit, requiring the kernel to perform OOB checks.
Implementations
Sourceimpl RudaCountSelection
impl RudaCountSelection
Sourcepub fn new<R>(client: &ComputeClient<R>, num_rudas: u32) -> RudaCountSelectionwhere
R: Runtime,
pub fn new<R>(client: &ComputeClient<R>, num_rudas: u32) -> RudaCountSelectionwhere
R: Runtime,
Creates a RudaCount while respecting the hardware limits.
Sourcepub fn ruda_count(self) -> RudaCount
pub fn ruda_count(self) -> RudaCount
Converts into RudaCount.